@@ -1,9 +1,10 @@
 """Database"""
 
 from .database import Database
-from ._utils import null, AttrDict
+from ._utils import null, Row
 from .column import Column, text, integer, blob, real
 from .signature import op
+from .operators import this
 from .table import Table
 
 
@@ -12,14 +13,15 @@ def test_installed():
     return True
 
 
-__version__ = "0.4.5"
+__version__ = "0.5.0"
 __all__ = [
     "Database",
     "Table",
+    "this",
     "op",
     "Column",
     "null",
-    "AttrDict",
+    "Row",
     "text",
     "integer",
     "real",
